"""
Django-RQ integration for django-cfg.

Provides REST API endpoints for monitoring and managing RQ task queues.
"""

default_app_config = 'django_cfg.apps.integrations.rq.apps.RQAppConfig'

__version__ = '1.0.0'
