{% extends 'django_tailwind/simple.html' %}
{% load django_cfg %}

{% block title %}404 - Page Not Found{% endblock %}

{% block icon %}🔍{% endblock %}

{% block heading %}Page Not Found{% endblock %}

{% block message %}
The page you're looking for doesn't exist or has been moved.
{% endblock %}

{% block actions %}
<a href="/cfg/admin/"
   class="inline-flex items-center justify-center px-6 py-3 border border-transparent rounded-lg shadow-sm text-base font-medium text-white bg-primary-600 hover:bg-primary-700 dark:bg-primary-500 dark:hover:bg-primary-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-primary-500 transition-colors">
    Go to Admin
</a>
<a href="/"
   class="inline-flex items-center justify-center px-6 py-3 border border-base-300 dark:border-base-600 rounded-lg shadow-sm text-base font-medium text-font-default-light dark:text-font-default-dark bg-white dark:bg-base-800 hover:bg-base-50 dark:hover:bg-base-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-primary-500 transition-colors">
    Go Home
</a>
{% endblock %}
