"""
Base configuration classes for extension modules.

Each module extension has a corresponding base settings class here.
"""

from .base import BaseModuleSettings

__all__ = [
    "BaseModuleSettings",
]
