from __future__ import annotations

from datetime import datetime
from typing import Any

from pydantic import BaseModel, ConfigDict, Field
{% if has_enums %}

from .enums import *
{% endif %}


{% for schema in schemas %}
{{ schema }}


{% endfor %}
