# Generated by Django 5.2.7 on 2025-11-01 13:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("grpc", "0001_initial"),
    ]

    operations = [
        migrations.RenameIndex(
            model_name="grpcrequestlog",
            new_name="django_cfg__service_584308_idx",
            old_name="django_cfg__service_4c4a8e_idx",
        ),
        migrations.RenameIndex(
            model_name="grpcrequestlog",
            new_name="django_cfg__method__5e704d_idx",
            old_name="django_cfg__method__8e1a7c_idx",
        ),
        migrations.RenameIndex(
            model_name="grpcrequestlog",
            new_name="django_cfg__status_a564a8_idx",
            old_name="django_cfg__status_f3d9a1_idx",
        ),
        migrations.RenameIndex(
            model_name="grpcrequestlog",
            new_name="django_cfg__user_id_f2ada7_idx",
            old_name="django_cfg__user_id_9c2b4f_idx",
        ),
        migrations.RenameIndex(
            model_name="grpcrequestlog",
            new_name="django_cfg__grpc_st_fea09f_idx",
            old_name="django_cfg__grpc_st_a7e5c2_idx",
        ),
    ]
