# Generated by Django 5.2.7 on 2025-11-03 09:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("grpc", "0003_grpcserverstatus"),
    ]

    operations = [
        migrations.AddField(
            model_name="grpcserverstatus",
            name="registered_services",
            field=models.JSONField(
                blank=True,
                default=list,
                help_text="List of registered service metadata (name, methods, etc.)",
            ),
        ),
    ]
