from enum import IntEnum, Enum

# Python 3.10 compatibility: StrEnum was added in Python 3.11
# Use str + Enum instead for backward compatibility
class StrEnum(str, Enum):
    """String Enum for Python 3.10+ compatibility"""
    pass


{% for enum in enums %}
{{ enum }}


{% endfor %}
