# Generated by Django 5.2.7 on 2025-11-04 05:30

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("grpc", "0005_grpcapikey"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AddField(
            model_name="grpcrequestlog",
            name="api_key",
            field=models.ForeignKey(
                blank=True,
                help_text="API key used for authentication (if applicable)",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="request_logs",
                to="grpc.grpcapikey",
            ),
        ),
        migrations.AddIndex(
            model_name="grpcrequestlog",
            index=models.Index(
                fields=["api_key", "-created_at"], name="django_cfg__api_key_218ecc_idx"
            ),
        ),
    ]
