from __future__ import annotations

from typing import Any, Optional

import httpx

{% for tag in tags %}
from .{{ tag.slug }} import {{ tag.class_name }}
{% endfor %}
from .logger import APILogger, LoggerConfig
from .retry import RetryConfig, RetryAsyncClient


{{ client_code }}
