{
  "name": "centrifugo-client",
  "version": "1.0.0",
  "description": "Generated Centrifugo WebSocket RPC client",
  "main": "index.ts",
  "types": "index.ts",
  "dependencies": {
    "centrifuge": "^5.0.0"
  },
  "devDependencies": {
    "typescript": "^5.0.0"
  }
}
