{% comment %}
Simple Image Display Widget
Shows image without modal (use image_preview for interactive version).
{% endcomment %}

<img
    src="{{ image_url }}"
    alt="{{ alt_text }}"
    {% if style %}style="{{ style }}"{% endif %}
    class="object-cover"
>
{% if caption %}
<br><small class="text-base-500 dark:text-base-400">{{ caption }}</small>
{% endif %}
